==> jc-1.4.0.tar.gz: soot/xml/Key.h <==
// public class soot.xml.Key

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 917f91ada5d5c7a0 soot_xml_Key

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_xml_Key_H_
#define _JC_soot_xml_Key_H_

// Forward structure declarations
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_xml_Key$sub_refs	_jc_soot_xml_Key$sub_refs;
typedef struct _jc_soot_xml_Key$sub_nonrefs	_jc_soot_xml_Key$sub_nonrefs;
typedef struct _jc_soot_xml_Key$refs	_jc_soot_xml_Key$refs;
typedef struct _jc_soot_xml_Key$nonrefs	_jc_soot_xml_Key$nonrefs;
typedef struct _jc_soot_xml_Key$object	_jc_soot_xml_Key$object;

typedef const struct _jc_soot_xml_Key$vmethods	_jc_soot_xml_Key$vmethods;
typedef const struct _jc_soot_xml_Key$vtable	_jc_soot_xml_Key$vtable;
typedef const struct _jc_soot_xml_Key$vtype	_jc_soot_xml_Key$vtype;

// Constructors
extern void _jc_soot_xml_Key$method$_init$7a03d5d0a68a368a(_jc_env *, struct _jc_soot_xml_Key$object *, jint, jint, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_soot_xml_Key$method$blue$b7dee708615eaa32(_jc_env *, struct _jc_soot_xml_Key$object *);
extern jint _jc_soot_xml_Key$method$green$53ef4b741280a296(_jc_env *, struct _jc_soot_xml_Key$object *);
extern struct _jc_java_lang_String$object *_jc_soot_xml_Key$method$key$dd25a381b3eaf34c(_jc_env *, struct _jc_soot_xml_Key$object *);
extern void _jc_soot_xml_Key$method$print$84f9c276d60ca634(_jc_env *, struct _jc_soot_xml_Key$object *, struct _jc_java_io_PrintWriter$object *);
extern jint _jc_soot_xml_Key$method$red$7d0da69269fa97dd(_jc_env *, struct _jc_soot_xml_Key$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_xml_Key$method_info$blue$b7dee708615eaa32;
extern _jc_method _jc_soot_xml_Key$method_info$green$53ef4b741280a296;
extern _jc_method _jc_soot_xml_Key$method_info$key$dd25a381b3eaf34c;
extern _jc_method _jc_soot_xml_Key$method_info$print$84f9c276d60ca634;
extern _jc_method _jc_soot_xml_Key$method_info$red$7d0da69269fa97dd;

// Virtual methods structure
struct _jc_soot_xml_Key$vmethods {
	jint	(*blue$b7dee708615eaa32)(_jc_env *, struct _jc_soot_xml_Key$object *);
	jint	(*green$53ef4b741280a296)(_jc_env *, struct _jc_soot_xml_Key$object *);
	struct _jc_java_lang_String$object	*(*key$dd25a381b3eaf34c)(_jc_env *, struct _jc_soot_xml_Key$object *);
	void	(*print$84f9c276d60ca634)(_jc_env *, struct _jc_soot_xml_Key$object *, struct _jc_java_io_PrintWriter$object *);
	jint	(*red$7d0da69269fa97dd)(_jc_env *, struct _jc_soot_xml_Key$object *);
};

// Vtable
struct _jc_soot_xml_Key$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_xml_Key$vmethods	soot_xml_Key;
};

// Vtype
struct _jc_soot_xml_Key$vtype {
	_jc_type			type;
	_jc_soot_xml_Key$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_xml_Key$sub_refs {
	struct _jc_java_lang_String$object	*key;
};

// Reference instance fields (object)
struct _jc_soot_xml_Key$refs {
    _jc_soot_xml_Key$sub_refs	soot_xml_Key;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_xml_Key$sub_nonrefs {
	jint	red;
	jint	green;
	jint	blue;
};

// Non-reference instance fields (object)
struct _jc_soot_xml_Key$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_xml_Key$sub_nonrefs	soot_xml_Key;
};

// Object instance structure
struct _jc_soot_xml_Key$object {
	_jc_soot_xml_Key$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_xml_Key$vtype	*vtype;
	_jc_soot_xml_Key$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_xml_Key$vtype _jc_soot_xml_Key$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_xml_Key, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_xml_Key$class_object;

#endif	/* _JC_soot_xml_Key_H_ */

==> jc-1.4.6.tar.gz: soot/xml/Key.h <==
// public class soot.xml.Key

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 917f91ada5d5c7a0 soot_xml_Key

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_xml_Key_H_
#define _JC_soot_xml_Key_H_

// Forward structure declarations
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_xml_Key$sub_refs	_jc_soot_xml_Key$sub_refs;
typedef struct _jc_soot_xml_Key$sub_nonrefs	_jc_soot_xml_Key$sub_nonrefs;
typedef struct _jc_soot_xml_Key$refs	_jc_soot_xml_Key$refs;
typedef struct _jc_soot_xml_Key$nonrefs	_jc_soot_xml_Key$nonrefs;
typedef struct _jc_soot_xml_Key$object	_jc_soot_xml_Key$object;

typedef const struct _jc_soot_xml_Key$vmethods	_jc_soot_xml_Key$vmethods;
typedef const struct _jc_soot_xml_Key$vtable	_jc_soot_xml_Key$vtable;
typedef const struct _jc_soot_xml_Key$vtype	_jc_soot_xml_Key$vtype;

// Constructors
extern void _jc_soot_xml_Key$method$_init$7a03d5d0a68a368a(_jc_env *, struct _jc_soot_xml_Key$object *, jint, jint, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_xml_Key$method$blue$b7dee708615eaa32(_jc_env *, struct _jc_soot_xml_Key$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_xml_Key$method$green$53ef4b741280a296(_jc_env *, struct _jc_soot_xml_Key$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_xml_Key$method$key$dd25a381b3eaf34c(_jc_env *, struct _jc_soot_xml_Key$object *) _JC_JCNI_ATTR;
extern void _jc_soot_xml_Key$method$print$84f9c276d60ca634(_jc_env *, struct _jc_soot_xml_Key$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_xml_Key$method$red$7d0da69269fa97dd(_jc_env *, struct _jc_soot_xml_Key$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_xml_Key$method_info$blue$b7dee708615eaa32;
extern _jc_method _jc_soot_xml_Key$method_info$green$53ef4b741280a296;
extern _jc_method _jc_soot_xml_Key$method_info$key$dd25a381b3eaf34c;
extern _jc_method _jc_soot_xml_Key$method_info$print$84f9c276d60ca634;
extern _jc_method _jc_soot_xml_Key$method_info$red$7d0da69269fa97dd;

// Virtual methods structure
struct _jc_soot_xml_Key$vmethods {
	jint	(*blue$b7dee708615eaa32)(_jc_env *, struct _jc_soot_xml_Key$object *) _JC_JCNI_ATTR;
	jint	(*green$53ef4b741280a296)(_jc_env *, struct _jc_soot_xml_Key$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*key$dd25a381b3eaf34c)(_jc_env *, struct _jc_soot_xml_Key$object *) _JC_JCNI_ATTR;
	void	(*print$84f9c276d60ca634)(_jc_env *, struct _jc_soot_xml_Key$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
	jint	(*red$7d0da69269fa97dd)(_jc_env *, struct _jc_soot_xml_Key$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_xml_Key$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_xml_Key$vmethods	soot_xml_Key;
};

// Vtype
struct _jc_soot_xml_Key$vtype {
	_jc_type			type;
	_jc_soot_xml_Key$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_xml_Key$sub_refs {
	struct _jc_java_lang_String$object	*key;
};

// Reference instance fields (object)
struct _jc_soot_xml_Key$refs {
    _jc_soot_xml_Key$sub_refs	soot_xml_Key;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_xml_Key$sub_nonrefs {
	jint	red;
	jint	green;
	jint	blue;
};

// Non-reference instance fields (object)
struct _jc_soot_xml_Key$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_xml_Key$sub_nonrefs	soot_xml_Key;
};

// Object instance structure
struct _jc_soot_xml_Key$object {
	_jc_soot_xml_Key$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_xml_Key$vtype	*vtype;
	_jc_soot_xml_Key$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_xml_Key$vtype _jc_soot_xml_Key$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_xml_Key, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_xml_Key$class_object;

#endif	/* _JC_soot_xml_Key_H_ */
